==> openshift-model-installer-5.12.0-sources.jar: io/fabric8/openshift/api/model/installer/ovirt/v1/CPUBuilder.java <==
package io.fabric8.openshift.api.model.installer.ovirt.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CPUBuilder extends io.fabric8.openshift.api.model.installer.ovirt.v1.CPUFluentImpl<io.fabric8.openshift.api.model.installer.ovirt.v1.CPUBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.installer.ovirt.v1.CPU,io.fabric8.openshift.api.model.installer.ovirt.v1.CPUBuilder>{
  public CPUBuilder() {
    this(false);
  }
  public CPUBuilder(java.lang.Boolean validationEnabled) {
    this(new CPU(), validationEnabled);
  }
  public CPUBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.CPUFluent<?> fluent) {
    this(fluent, false);
  }
  public CPUBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.CPUFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CPU(), validationEnabled);
  }
  public CPUBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.CPUFluent<?> fluent,io.fabric8.openshift.api.model.installer.ovirt.v1.CPU instance) {
    this(fluent, instance, false);
  }
  public CPUBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.CPUFluent<?> fluent,io.fabric8.openshift.api.model.installer.ovirt.v1.CPU instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCores(instance.getCores()); 
    fluent.withSockets(instance.getSockets()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CPUBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.CPU instance) {
    this(instance,false);
  }
  public CPUBuilder(io.fabric8.openshift.api.model.installer.ovirt.v1.CPU instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCores(instance.getCores()); 
    this.withSockets(instance.getSockets()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.installer.ovirt.v1.CPUFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.installer.ovirt.v1.CPU build() {
    CPU buildable = new CPU(fluent.getCores(),fluent.getSockets());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CPUBuilder that = (CPUBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-installer-6.2.0-sources.jar: io/fabric8/openshift/api/model/installer/ovirt/v1/CPUBuilder.java <==
package io.fabric8.openshift.api.model.installer.ovirt.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CPUBuilder extends CPUFluentImpl<CPUBuilder> implements VisitableBuilder<CPU,CPUBuilder>{
  public CPUBuilder() {
    this(false);
  }
  public CPUBuilder(Boolean validationEnabled) {
    this(new CPU(), validationEnabled);
  }
  public CPUBuilder(CPUFluent<?> fluent) {
    this(fluent, false);
  }
  public CPUBuilder(CPUFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CPU(), validationEnabled);
  }
  public CPUBuilder(CPUFluent<?> fluent,CPU instance) {
    this(fluent, instance, false);
  }
  public CPUBuilder(CPUFluent<?> fluent,CPU instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCores(instance.getCores()); 
    fluent.withSockets(instance.getSockets()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CPUBuilder(CPU instance) {
    this(instance,false);
  }
  public CPUBuilder(CPU instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withCores(instance.getCores()); 
    this.withSockets(instance.getSockets()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  CPUFluent<?> fluent;
  Boolean validationEnabled;
  public CPU build() {
    CPU buildable = new CPU(fluent.getCores(),fluent.getSockets());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
